# MAJIS operations toolbox history

All notable changes to MAJIS operations toolbox will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


[Unreleased][new]
-----------------
[new]: https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/compare/1.1.0...main


[Release 1.1.0 - 2024/06/19][1.1.0]
-----------------------------------
[1.1.0]: https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/releases/1.1.0

### Added
- Add generic ITL writer `save_itl` to export a ITL timeline to different formats ([!9](https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/merge_requests/9)).
- Add ITL JSON reader and writer with validator on SOC and MAJIS schema ([!9](https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/merge_requests/9)).
- SonarQube code quality job in Gitlab CI ([!7](https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/merge_requests/7)).

### Changed
- Isolate ITL text reader in EPS format in its own sub-module ([!9](https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/merge_requests/9)).
- Isolate export to ITL EPS, JSON, CSV, XLS in their own sub-modules ([!9](https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/merge_requests/9)).
- ITL EPS comments are now reformatted rather than copy-pasted ([!9](https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/merge_requests/9)).
- Project status is now considered `stable`.

### Fixed
- Fix invalid timeline template format ([!8](https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/merge_requests/8)).
- Fix ITL reader with missing space and single comment.
- Fix missing sphinx config for RTD.
- Gitlab-CI unquoted hatch version.
- Gitlab-CI build project before PyPI publication.
- Gitlab-CI add user `__token__` value for PyPI publication.

### Removed
- `.comments` properties from parsed `EventWindow` objects ([!9](https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/merge_requests/9)).


[Release 1.0.0 - 2024/06/19][1.0.0]
-----------------------------------
[1.0.0]: https://git.ias.u-psud.fr/majis_sgs/operations/majis-ops-toolbox/-/releases/1.0.0

### Added

- Add `read_itl()`, `save_itl()`, `save_csv()` and `save_xlsm()` methods.
- Add `Timeline` object to manipulate MAJIS `.xlsm` timeline file.
- Add `majis-itl` command line interface.
- Project init
